==> music_player-fabric-1.19.4-2.6.0.326-sources.jar: info/u_team/music_player/gui/playlist/GuiMusicPlaylistListEntryPlayable.java <==
package info.u_team.music_player.gui.playlist;

import info.u_team.music_player.gui.util.GuiTrackUtils;
import info.u_team.music_player.init.MusicPlayerResources;
import info.u_team.music_player.lavaplayer.api.audio.IAudioTrack;
import info.u_team.music_player.lavaplayer.api.queue.ITrackManager;
import info.u_team.music_player.musicplayer.MusicPlayerManager;
import info.u_team.music_player.musicplayer.playlist.LoadedTracks;
import info.u_team.music_player.musicplayer.playlist.Playlist;
import info.u_team.music_player.musicplayer.playlist.Playlists;
import info.u_team.u_team_core.gui.elements.ImageToggleButton;
import net.minecraft.class_4587;

public abstract class GuiMusicPlaylistListEntryPlayable extends GuiMusicPlaylistListEntry {
	
	private final ITrackManager manager;
	private final IAudioTrack track;
	
	private final LoadedTracks loadedTrack;
	
	protected final ImageToggleButton playTrackButton;
	
	GuiMusicPlaylistListEntryPlayable(Playlists playlists, Playlist playlist, LoadedTracks loadedTrack, IAudioTrack track) {
		this.track = track;
		this.loadedTrack = loadedTrack;
		manager = MusicPlayerManager.getPlayer().getTrackManager();
		
		playTrackButton = addChildren(new ImageToggleButton(0, 0, 20, 20, MusicPlayerResources.TEXTURE_PLAY, MusicPlayerResources.TEXTURE_PAUSE, false));
		
		if (loadedTrack.hasError() || track == null) {
			playTrackButton.field_22764 = false;
		} else {
			playTrackButton.setToggled(track == getCurrentlyPlaying());
			playTrackButton.setPressable(() -> {
				final boolean play = playTrackButton.isToggled();
				if (play) {
					if (manager.isPaused() && getCurrentlyPlaying() == track) {
						manager.setPaused(false);
					} else {
						playlists.setPlaying(playlist);
						playlist.setPlayable(loadedTrack, track);
						manager.setTrackQueue(playlist);
						manager.start();
					}
				} else {
					manager.setPaused(true);
				}
			});
		}
	}
	
	@Override
	public boolean method_25402(double mouseX, double mouseY, int button) {
		if (button == 2) {
			final String uri = this instanceof GuiMusicPlaylistListEntryPlaylistStart || this instanceof GuiMusicPlaylistListEntryError ? loadedTrack.getUri().get() : track.getInfo().getURI();
			if (GuiTrackUtils.openURI(uri)) {
				return true;
			}
		}
		return super.method_25402(mouseX, mouseY, button);
	}
	
	@Override
	public void method_25343(class_4587 matrixStack, int slotIndex, int entryY, int entryX, int entryWidth, int entryHeight, int mouseX, int mouseY, boolean hovered, float partialTicks) {
		playTrackButton.method_46421(entryWidth - 65);
		playTrackButton.method_46419(entryY + 8);
		playTrackButton.method_25394(matrixStack, mouseX, mouseY, partialTicks);
	}
	
	@Override
	protected void tick() {
		if (isPlaying()) {
			playTrackButton.setToggled(!manager.isPaused());
		} else {
			playTrackButton.setToggled(false);
		}
	}
	
	protected IAudioTrack getCurrentlyPlaying() {
		return manager.getCurrentTrack() == null ? null : manager.getCurrentTrack().getOriginalTrack();
	}
	
	protected boolean isPlaying() {
		return getCurrentlyPlaying() == track;
	}
	
	public IAudioTrack getTrack() {
		return track;
	}
	
	public ImageToggleButton getPlayTrackButton() {
		return playTrackButton;
	}
}

==> music_player-fabric-1.21.1-2.7.1.351-sources.jar: info/u_team/music_player/gui/playlist/GuiMusicPlaylistListEntryPlayable.java <==
package info.u_team.music_player.gui.playlist;

import info.u_team.music_player.gui.util.GuiTrackUtils;
import info.u_team.music_player.init.MusicPlayerResources;
import info.u_team.music_player.lavaplayer.api.audio.IAudioTrack;
import info.u_team.music_player.lavaplayer.api.audio.IPlayingTrack;
import info.u_team.music_player.lavaplayer.api.queue.ITrackManager;
import info.u_team.music_player.musicplayer.MusicPlayerManager;
import info.u_team.music_player.musicplayer.playlist.LoadedTracks;
import info.u_team.music_player.musicplayer.playlist.Playlist;
import info.u_team.music_player.musicplayer.playlist.Playlists;
import info.u_team.u_team_core.gui.elements.ImageToggleButton;
import net.minecraft.class_332;

public abstract class GuiMusicPlaylistListEntryPlayable extends GuiMusicPlaylistListEntry {
	
	private final ITrackManager manager;
	private final IAudioTrack track;
	
	private final LoadedTracks loadedTrack;
	
	protected final ImageToggleButton playTrackButton;
	
	GuiMusicPlaylistListEntryPlayable(Playlists playlists, Playlist playlist, LoadedTracks loadedTrack, IAudioTrack track) {
		this.track = track;
		this.loadedTrack = loadedTrack;
		manager = MusicPlayerManager.getPlayer().getTrackManager();
		
		playTrackButton = addChildren(new ImageToggleButton(0, 0, 20, 20, MusicPlayerResources.TEXTURE_PLAY, MusicPlayerResources.TEXTURE_PAUSE, false));
		
		if (loadedTrack.hasError() || track == null) {
			playTrackButton.field_22764 = false;
		} else {
			playTrackButton.setToggled(track == getCurrentlyPlaying());
			playTrackButton.setPressable(() -> {
				final boolean play = playTrackButton.isToggled();
				if (play) {
					if (manager.isPaused() && getCurrentlyPlaying() == track) {
						manager.setPaused(false);
					} else {
						playlists.setPlaying(playlist);
						playlist.setPlayable(loadedTrack, track);
						manager.setTrackQueue(playlist);
						manager.start();
					}
				} else {
					manager.setPaused(true);
				}
			});
		}
	}
	
	@Override
	public boolean method_25402(double mouseX, double mouseY, int button) {
		if (button == 2) {
			final String uri = this instanceof GuiMusicPlaylistListEntryPlaylistStart || this instanceof GuiMusicPlaylistListEntryError ? loadedTrack.getUri().get() : track.getInfo().getURI();
			if (GuiTrackUtils.openURI(uri)) {
				return true;
			}
		}
		return super.method_25402(mouseX, mouseY, button);
	}
	
	@Override
	public void method_25343(class_332 guiGraphics, int slotIndex, int entryY, int entryX, int entryWidth, int entryHeight, int mouseX, int mouseY, boolean hovered, float partialTicks) {
		playTrackButton.method_46421(entryWidth - 65);
		playTrackButton.method_46419(entryY + 8);
		playTrackButton.method_25394(guiGraphics, mouseX, mouseY, partialTicks);
	}
	
	@Override
	protected void tick() {
		if (isPlaying()) {
			playTrackButton.setToggled(!manager.isPaused());
		} else {
			playTrackButton.setToggled(false);
		}
	}
	
	protected IAudioTrack getCurrentlyPlaying() {
		final IPlayingTrack track = manager.getCurrentTrack();
		return track == null ? null : track.getOriginalTrack();
	}
	
	protected boolean isPlaying() {
		return getCurrentlyPlaying() == track;
	}
	
	public IAudioTrack getTrack() {
		return track;
	}
	
	public ImageToggleButton getPlayTrackButton() {
		return playTrackButton;
	}
}
